Module rerank
khive_
pack_
memory
0.2.6
Module rerank
Module Items
Structs
Functions
In crate khive_
pack_
memory
khive_pack_memory
Module
rerank
Structs

Rerank
Features
Input features available per recall candidate for weighted reranking.
Functions

weighted_
rerank
Compute a weighted feature-combination rerank score, normalized by the sum of recognized positive weights.