Module rerank

Module rerank 

Structs

RerankFeatures
Input features available per recall candidate for weighted reranking.

Functions

weighted_rerank
Compute a weighted feature-combination rerank score, normalized by the sum of recognized positive weights.